LINE = "line"
DOT = "dot"
MINI_DOT = "minidot"
JUMP = "jump"
PULSE = "pulse"
POINTS = "points"
GLOBE = "globe"
MOON = "moon"
MONKEY = "monkey"
METER = "meter"
HAMBURGER = "hamburger"


def get_all_spinner_types():
    return [
        LINE,
        DOT,
        MINI_DOT,
        JUMP,
        PULSE,
        POINTS,
        GLOBE,
        MOON,
        MONKEY,
        METER,
        HAMBURGER,
    ]
