class FlagTypeChoice:
    COLOR = "color"
    INT = "integer"
    STR = "string"
    BOOL = "boolean"
    ALIGN = "alignment"
    POSITION = "position"
    BORDER = "border"
    FORMAT = "format"
    SPINNER = "spinner"


class FlagSeparatorChoice:
    DOT = "."
    HYPHEN = "-"
