LEFT = "left"
CENTER = "center"
RIGHT = "right"
BOTTOM = "bottom"
MIDDLE = "middle"
TOP = "top"


def all_alignment_types():
    return [
        LEFT,
        CENTER,
        RIGHT,
        BOTTOM,
        MIDDLE,
        TOP,
    ]
